
* PROGRAM: COST_SHARING_DME.SAS;
* DESCRIPTION: PERFORM COST SHARING ALGORITHM FOR DME CLAIMS;

DATA DME_BASEID;
RETAIN JOIN_ID '1';
SET &INC(WHERE=(CATEGORY='11a'));
RUN;

data DME_FILE;
    SET  PBP_FILE(KEEP =
                   CONTRACT_ID PLAN_ID SEGMENT_ID HPLAN
                   PBP_B11A_DED_AMT PBP_B11A_MAXENR_AMT
                   PBP_B11A_MAXENR_PER PBP_B11A_COINS_PCT_MC PBP_B11A_COPAY_MC_AMT);
  join_id = '1';
run;

proc sql;
  create table cat_join as
      (select b.category, b.baseid, b.visits, b.amttot, b.year, p.*
      from DME_BASEID b, DME_FILE p
      where b.join_id = p.join_id)
    ;
quit;
run;

%MACRO DME_COST_SHARE(SERV_CAT);

%LET SERV_CAT = DME;
  DATA &SERV_CAT;
    set cat_join (drop = join_id);
    COST_SHARE_COST = 0;
    OTHER_COST = 0;

    IF PBP_B11A_MAXENR_AMT NE . THEN BENE_MAXIMUM = PBP_B11A_MAXENR_AMT;

      IF PBP_B11A_DED_AMT = . THEN DO;
        COST = SUM(COST, (VISITS * PBP_B11A_COPAY_MC_AMT));
        COST = SUM(COST, AMTTOT * PBP_B11A_COINS_PCT_MC);
      END;
      ELSE DO;
        IF AMTTOT <= PBP_B11A_DED_AMT THEN DO;
          COST = AMTTOT;
        END;
        ELSE DO;
          COST = PBP_B11A_DED_AMT;
          DEDUCT_SHARE = PBP_B11A_DED_AMT / AMTTOT;
          AMTTOT = SUM(AMTTOT,-PBP_B11A_DED_AMT);
          VISITS = VISITS * (1 - DEDUCT_SHARE);
          COST = SUM(COST, (VISITS * PBP_B11A_COPAY_MC_AMT));
          COST = SUM(COST, AMTTOT * PBP_B11A_COINS_PCT_MC);
        END;
      END;

    IF BENE_MAXIMUM >= 0 AND COST >= 0 THEN COST = MIN(COST, BENE_MAXIMUM);

    COST_SHARE_COST = COST;

    COST_SHARE_COST_MC  = COST;
    COST_SHARE_COST_AMO = 0;

    CATEGORY = "11a";
  RUN;

%MEND DME_COST_SHARE;

%MACRO RUN_COST;
%LET CAT=DME;
RUN;
%DME_COST_SHARE(&CAT);

%MEND RUN_COST;

%RUN_COST;
RUN;

PROC APPEND DATA=DME(KEEP=HPLAN YEAR BASEID COST_SHARE_COST COST_SHARE_COST_MC COST_SHARE_COST_AMO
       OTHER_COST COST CATEGORY AMTTOT)  BASE= COSTDATA FORCE;
RUN;

PROC DATASETS LIBRARY=WORK NODETAILS NOLIST;
DELETE DME DME_BASEID DME_FILE CAT_JOIN;
QUIT;
RUN;
